@@ -254,13 +254,17 @@ class Transport(ThreadManager):
 
         self._encode_body_payload(data)
 
-        data["metadata"] = {
-            "configuration": {
-                "api": {
-                    "uuid": api_config['uuid'] if api_config else ""
-                }
+        configuration_metadata = {
+            "api": {
+                "uuid": api_config['uuid'] if api_config else ""
             }
         }
+        if 'metadata' in data:
+            data['metadata']['configuration'] = configuration_metadata
+        else:
+            data["metadata"] = {
+                "configuration": configuration_metadata
+            }
         return data
 
     def _init_buffer(self):
